@@ -11,10 +11,7 @@
            "\n",
            paste("See",
                  sQuote("library(help=\"AFR\")"),
-                 "for details."),
-           "\n",
-            paste("Please fill in the form", sQuote("https://forms.gle/anRQ8WZbTQ5hQetg9"),
-                  "It is necessary for the analysis of the users of our package.", "\n"))
+                 "for details."))
 
   if(interactive() || getOption("verbose"))
   packageStartupMessage(paste(strwrap(txt,
@@ -22,6 +19,5 @@
                                         exdent = 4),
                                 collapse = "\n"))
 
-
 }
 
